;
;****************************************************************************
;
;  Purpose:
;	Common System Macros
;
;  Date:
;	11/23/93
;
;  Author:
;	John C. Wren
;
;  Modications:
;	02/04/97 - Added Description Fields For Archive
;
;  Processor:
;	Generic 8031
;
;  Assembler:
;	Avocet AVA51
;
;  Dependencies:
;	None
;
;  Files:
;	None
;
;  Philosophic:
;	None
;
;****************************************************************************
;
;  Description:
;	Delay 'n' Nanoseconds Of Time
;
;  Entry Requirements:
;	None
;
;  On Exit:
;	None
;
;  Affected:
;	None
;
;  Stack:
;	1 Bytes, Not Including Space Used By Called Routines
;
;  Comments:
;	Delay Time Is Specified In Nanoseconds, i.e. 2.9us Is 2900.  The
;	Values Should Be Adjusted So That It Rounds Up To The Next Even
;	Instruction Time.  The Loop Is Used When The Number Of Nanoseconds
;	Used For NOPs Exceeds The Time For 1 Pass Through The Loop Method.
;	This Could Probably Be Improved By Having A Equates That Specifies
;	The Instruction Time, And Number Of Clocks Per Instruction, But Most
;	Of My Projects Use 1 Of 3 Clocks (11.0592, 12, 22.1184).
;
MDELAY	%macro	delaytime
	%if	(delaytime ge 8680)
	push	0				 ; 2.170us @ 11.0592mhz @ AT89C51	
	mov	r0,#((delaytime - 6510) / 2170)+1; 2.170us @ 11.0592mhz @ AT89C51	
	djnz	r0,$				 ; 2.170us @ 11.0592mhz @ AT89C51	
	pop	0				 ; 2.170us @ 11.0592mhz @ AT89C51
	%else
	%for	arf = 1 to ((delaytime / 1085) + 1)
	nop					 ; 1.085us @ 11.0592mhz @ AT89C51
	%endfor
	%endif
	%endm
;
;****************************************************************************
;
;  Description:
;	Performs A STOP Function By Disabling Interrupts And Looping
;
;  Entry Requirements:
;	None
;
;  On Exit:
;	None
;
;  Affected:
;	None
;
;  Stack:
;	None
;
;  Comments:
;	None
;
stop	%macro
	clr	ea
	jmp	$
	%endm
; 
;****************************************************************************
;
;  Description:
;	Implements A Compare And Jump Equal Function
;
;  Entry Requirements:
;	None
;
;  On Exit:
;	None
;
;  Affected:
;	PSW.CY
;
;  Stack:
;	None
;
;  Comments:
;	None
;
cjeq    %macro  parm1,parm2,parm3
	%gensym	temp
        cjne    parm1,parm2,temp
        jmp    	parm3
temp
        %endm
;****************************************************************************
;
;  Description:
;	Implements A Compare And Jump Less Than Instruction
;
;  Entry Requirements:
;	None
;
;  On Exit:
;	None
;
;  Affected:
;	PSW.CY
;
;  Stack:
;	None
;
;  Comments:
;	None
;
cjlt    %macro  parm1,parm2,parm3
	%gensym	temp
        cjne    parm1,parm2,temp
temp	jc      parm3
        %endm
;****************************************************************************
;
;  Description:
;	Implements A Compare And Jump Less Or Equal Instruction
;
;  Entry Requirements:
;	None
;
;  On Exit:
;	None
;
;  Affected:
;	PSW.CY
;
;  Stack:
;	None
;
;  Comments:
;	None
;
cjle    %macro  parm1,parm2,parm3
	%gensym	temp
        cjne    parm1,parm2,temp
	jmp	parm3
temp	jc      parm3
        %endm
;****************************************************************************
;
;  Description:
;	Implements A Compare And Jump Greater Than Instruction
;
;  Entry Requirements:
;	None
;
;  On Exit:
;	None
;
;  Affected:
;	PSW.CY
;
;  Stack:
;	None
;
;  Comments:
;	None
;
cjgt    %macro  parm1,parm2,parm3
	%gensym	temp
	%gensym	temp2
        cjne    parm1,parm2,temp
	jmp	temp2
temp	jnc     parm3
temp2
        %endm
;****************************************************************************
;
;  Description:
;	Implements A Compare And Jump Greater Than Or Equal Instruction
;
;  Entry Requirements:
;	None
;
;  On Exit:
;	None
;
;  Affected:
;	PSW.CY
;
;  Stack:
;	None
;
;  Comments:
;	None
;
cjge    %macro  parm1,parm2,parm3
	%gensym	temp
        cjne    parm1,parm2,temp
temp	jnc     parm3
        %endm
;        
;****************************************************************************
; 

